@@ -54,7 +54,7 @@ void NvidiaPlugin::setup()
     m_process->setProgram(m_sniExecutablePath);
     m_process->setArguments({QStringLiteral("pmon")});
 
-    connect(m_process, &QProcess::readyReadStandardOutput, this, [=]() {
+    connect(m_process, &QProcess::readyReadStandardOutput, this, [this]() {
         while (m_process->canReadLine()) {
             const QString line = QString::fromLatin1(m_process->readLine());
             if (line.startsWith(QLatin1Char('#'))) { // comment line
@@ -65,11 +65,7 @@ void NvidiaPlugin::setup()
                 }
                 continue;
             }
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-            const auto parts = line.splitRef(QLatin1Char(' '), Qt::SkipEmptyParts);
-#else
             const auto parts = QStringView(line).split(QLatin1Char(' '), Qt::SkipEmptyParts);
-#endif
 
             // format at time of writing is
             // # gpu        pid  type    sm   mem   enc   dec   command
